#[non_exhaustive]pub struct CheckedEggRewriteProofV0 {
pub specificity: EggRewriteClaimEvidenceV0,
pub provenance: EggRewriteClaimEvidenceV0,
pub cascade_safety: EggRewriteClaimEvidenceV0,
/* private fields */
}Expand description
Additive typed replacement for the legacy Boolean proof carrier.
Computed-value preservation remains the existing obligation-family lookup; it is intentionally not represented as a fourth evidence claim.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.specificity: EggRewriteClaimEvidenceV0provenance: EggRewriteClaimEvidenceV0cascade_safety: EggRewriteClaimEvidenceV0Implementations
Sourceimpl CheckedEggRewriteProofV0
impl CheckedEggRewriteProofV0
pub fn new( specificity: EggRewriteClaimEvidenceV0, obligation_family: ObligationFamilyIdV0, provenance: EggRewriteClaimEvidenceV0, cascade_safety: EggRewriteClaimEvidenceV0, ) -> Self
pub const fn obligation_family(&self) -> ObligationFamilyIdV0
pub const fn computed_value_preserved(&self) -> bool